
From: Lennert Buytenhek <buytenh@marvell.com>
Subject: gdb: enable build on ARM

This patch makes gdb build on ARM:
- Don't require prelink on ARM.
- Don't build with -Werror, as some ARM-related source files
  cause some warnings that are harmless and shouldn't fail the
  build.
- Delete the ARM instruction simulator-related bits from the install
  root so as not to have rpm bomb out in the packaging stage due to
  unpackaged files.

Signed-off-by: Lennert Buytenhek <buytenh@marvell.com>

Index: SPECS/gdb.spec
===================================================================
--- SPECS.orig/gdb.spec
+++ SPECS/gdb.spec
@@ -11,7 +11,7 @@ Name: gdb
 Version: 6.6
 
 # The release always contains a leading reserved number, start it at 1.
-Release: 36%{?dist}
+Release: 36%{?dist}.fa1
 
 License: GPL
 Group: Development/Debuggers
@@ -403,7 +403,9 @@ BuildRequires: /lib/libc.so.6 %{_exec_pr
 %ifarch ia64
 BuildRequires: libunwind-devel >= 0.99-0.1.frysk20070405cvs
 Requires: libunwind >= 0.99-0.1.frysk20070405cvs
-%else
+%endif
+
+%ifnarch %{arm} ia64
 BuildRequires: prelink
 %endif
  
@@ -600,6 +602,9 @@ enable_build_warnings="$enable_build_war
 	$enable_build_warnings				\
 	--with-separate-debug-dir=/usr/lib/debug	\
 	--disable-rpath					\
+%ifarch %{arm}
+	--disable-werror				\
+%endif
 %ifarch ia64
 	--with-libunwind				\
 %else
@@ -673,6 +678,10 @@ rm -rf $RPM_BUILD_ROOT/%{_libdir}/lib{bf
 
 rm -f $RPM_BUILD_ROOT%{_infodir}/dir
 
+# We aren't interested in the simulator.
+
+rm -f $RPM_BUILD_ROOT%{_libdir}/lib*-sim.a
+
 %clean
 rm -rf $RPM_BUILD_ROOT
 
